<?php
namespace Bushelpowered\Api\Aggregator\Quoting\V1\Response;
        
class QuoteRequestDetailResponse implements \Bushelpowered\Api\Common\HasCreatedAtTimestamp, \Bushelpowered\Api\Common\HasUpdatedAtTimestamp
{
    /** @var string $id The primary unique identifier.*/
    public string $id;
    /** @var string $accountId The UUID of the account associated with the quote request*/
    public string $accountId;
    /** @var string $accountName */
    public string $accountName;
    /** @var string $name The name of the quote request*/
    public string $name;
    /** @var null|string $commodityId The UUID of the commodity associated with the quote request*/
    public ?string $commodityId = null;
    /** @var string $commodityName */
    public string $commodityName;
    /** @var string $customerName The name of the customer associated with the quote request*/
    public string $customerName;
    /** @var string $fieldNames The field names for the quote request*/
    public string $fieldNames;
    /** @var null|int $area The acres/hectares for the quote request*/
    public ?int $area = null;
    /** @var string $areaUoM Unit of measure for land area, either acre or hectare*/
    public string $areaUoM;
    /** @var null|int $cropYear The crop year of the quote request*/
    public ?int $cropYear = null;
    /** @var string $creationDate The creation date of the quote request of yyyy-MM-dd format, IE: 2023-10-04*/
    public string $creationDate;
    /** @var string $customerComments The customer comments of the quote request*/
    public string $customerComments;
    /** @var string $status The status of the request: draft, requested, converted (staff user converted a request into a quote but has not sent it yet), sent (for review by grower)*/
    public string $status;
    /** @var string $createdBy */
    public string $createdBy;
    /** @var string $updatedBy */
    public string $updatedBy;
    /** @var \Bushelpowered\Api\Aggregator\Quoting\V1\Response\LineItemRequestResponse[] $lineItems */
    public array $lineItems;
    /** @var \Bushelpowered\Api\Aggregator\Quoting\V1\Response\ServiceRequestResponse[] $services */
    public array $services;
    /** @var string $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;
    /** @var string $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;

    /**
     * @param  string  $id The primary unique identifier.
     * @param  string  $accountId The UUID of the account associated with the quote request
     * @param  string  $accountName 
     * @param  string  $name The name of the quote request
     * @param  null|string  $commodityId The UUID of the commodity associated with the quote request
     * @param  string  $commodityName 
     * @param  string  $customerName The name of the customer associated with the quote request
     * @param  string  $fieldNames The field names for the quote request
     * @param  null|int  $area The acres/hectares for the quote request
     * @param  string  $areaUoM Unit of measure for land area, either acre or hectare
     * @param  null|int  $cropYear The crop year of the quote request
     * @param  string  $creationDate The creation date of the quote request of yyyy-MM-dd format, IE: 2023-10-04
     * @param  string  $customerComments The customer comments of the quote request
     * @param  string  $status The status of the request: draft, requested, converted (staff user converted a request into a quote but has not sent it yet), sent (for review by grower)
     * @param  string  $createdBy 
     * @param  string  $updatedBy 
     * @param  \Bushelpowered\Api\Aggregator\Quoting\V1\Response\LineItemRequestResponse[]  $lineItems 
     * @param  \Bushelpowered\Api\Aggregator\Quoting\V1\Response\ServiceRequestResponse[]  $services 
     * @param  string  $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $id, string $accountId, string $accountName, string $name, ?string $commodityId, string $commodityName, string $customerName, string $fieldNames, ?int $area, string $areaUoM, ?int $cropYear, string $creationDate, string $customerComments, string $status, string $createdBy, string $updatedBy, array $lineItems, array $services, string $createdAt, string $updatedAt)
    {
        $this->id = $id;
        $this->accountId = $accountId;
        $this->accountName = $accountName;
        $this->name = $name;
        $this->commodityId = $commodityId;
        $this->commodityName = $commodityName;
        $this->customerName = $customerName;
        $this->fieldNames = $fieldNames;
        $this->area = $area;
        $this->areaUoM = $areaUoM;
        $this->cropYear = $cropYear;
        $this->creationDate = $creationDate;
        $this->customerComments = $customerComments;
        $this->status = $status;
        $this->createdBy = $createdBy;
        $this->updatedBy = $updatedBy;
        $this->lineItems = $lineItems;
        $this->services = $services;
        $this->createdAt = $createdAt;
        $this->updatedAt = $updatedAt;
    }
    
    /**
     * @return string Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
    /**
     * @return string Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getUpdatedAt(): string
    {
        return $this->updatedAt;
    }
}