<?php
namespace Bushelpowered\Api\Trade\Offers\V1\Events;
        
class OrderEvent implements \Bushelpowered\Api\Common\Event\Event
{
    /** @var string $datasourceId */
    public string $datasourceId;
    /** @var \Bushelpowered\Api\Trade\Offers\V1\OrderStatus $status */
    public \Bushelpowered\Api\Trade\Offers\V1\OrderStatus $status;
    /** @var \Bushelpowered\Api\Trade\Offers\V1\Model\OrderStandard $data */
    public \Bushelpowered\Api\Trade\Offers\V1\Model\OrderStandard $data;
    /** @var string $idempotencyKey A key to uniquely identify this event.*/
    public string $idempotencyKey;
    /** @var string $eventCreationTime The time the event was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $eventCreationTime;
    /** @var null|string $tenantId The tenant that this event belongs to/was emitted for. Null if an event is not for a specific tenant.*/
    public ?string $tenantId = null;

    /**
     * @param  string  $datasourceId 
     * @param  \Bushelpowered\Api\Trade\Offers\V1\OrderStatus  $status 
     * @param  \Bushelpowered\Api\Trade\Offers\V1\Model\OrderStandard  $data 
     * @param  string  $idempotencyKey A key to uniquely identify this event.
     * @param  string  $eventCreationTime The time the event was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $tenantId The tenant that this event belongs to/was emitted for. Null if an event is not for a specific tenant.
     */
    public function __construct(string $datasourceId, \Bushelpowered\Api\Trade\Offers\V1\OrderStatus $status, \Bushelpowered\Api\Trade\Offers\V1\Model\OrderStandard $data, string $idempotencyKey, string $eventCreationTime, ?string $tenantId)
    {
        $this->datasourceId = $datasourceId;
        $this->status = $status;
        $this->data = $data;
        $this->idempotencyKey = $idempotencyKey;
        $this->eventCreationTime = $eventCreationTime;
        $this->tenantId = $tenantId;
    }
    
    /**
     * @return string A key to uniquely identify this event.
     */
    public function getIdempotencyKey(): string
    {
        return $this->idempotencyKey;
    }
    /**
     * @return string The time the event was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getEventCreationTime(): string
    {
        return $this->eventCreationTime;
    }
    /**
     * @return null|string The tenant that this event belongs to/was emitted for. Null if an event is not for a specific tenant.
     */
    public function getTenantId(): ?string
    {
        return $this->tenantId;
    }
}